#[unsafe(no_mangle)]pub extern "C" fn pxs_addmod(module_ptr: *mut pxs_Module)Expand description
Add the module finally to the runtime.
After this you can forget about the ptr since PM handles it.
#[unsafe(no_mangle)]pub extern "C" fn pxs_addmod(module_ptr: *mut pxs_Module)Add the module finally to the runtime.
After this you can forget about the ptr since PM handles it.