pxs_execlua

Function pxs_execlua 

#[unsafe(no_mangle)]
pub extern "C" fn pxs_execlua( code: *const c_char, file_name: *const c_char, ) -> *mut c_char
Execute some lua code. Will return a String, an empty string means that the code executed succesffuly

The result needs to be freed by calling pxs_free_str