pxs_execpython

Function pxs_execpython 

#[unsafe(no_mangle)]
pub extern "C" fn pxs_execpython( code: *const c_char, file_name: *const c_char, ) -> *mut c_char
Execute some Python code. Will return a String, an empty string means that the code executed successfully.

The result needs to be freed by calling pxs_free_str