pxs_listadd

Function pxs_listadd 

#[unsafe(no_mangle)]
pub extern "C" fn pxs_listadd( list: *mut pxs_Var, item: *mut pxs_Var, ) -> i32
Add a item to a pxs_VarList.

Expects a pointer to pxs_VarList. And a pointer for the item to add (pxs_Var*)

This will take ownership of the added item. If you want to copy it instead first create a new pxs_Var with pxs_var_newcopy(item)

Will return the index added at.