#[unsafe(no_mangle)]pub extern "C" fn pxs_newarena()Expand description
Create a new arena in memory.
This does not return anything, it simply creates a scope that will allocate pxs_Var memory.
when finished call, pxs_freearena
#[unsafe(no_mangle)]pub extern "C" fn pxs_newarena()Create a new arena in memory.
This does not return anything, it simply creates a scope that will allocate pxs_Var memory.
when finished call, pxs_freearena