pxs_objectcall

Function pxs_objectcall 

#[unsafe(no_mangle)]
pub extern "C" fn pxs_objectcall( runtime: *mut pxs_Var, var: *mut pxs_Var, method: *const c_char, args: *mut pxs_Var, ) -> pxs_VarT
Object call.

All memory is borrowed except for args. But the var returned need to be freed on host side if not returned by a function.

You can get the runtime from the first Var in any callback.

Example

    // Inside a Var* method
    Var* obj = argv[1];
    Var name = pxs_object_call()