#[unsafe(no_mangle)]pub extern "C" fn pxs_stopthread()Expand description
Tells PixelScript that we just stopped the most recent thread.
#[unsafe(no_mangle)]pub extern "C" fn pxs_stopthread()Tells PixelScript that we just stopped the most recent thread.