macro_rules! own_string {
($cstr:expr) => { ... };
}Expand description
Convert a owned C string (i.e. owned by us now.) into a Rust String.
The C memory will be freed automatically, and you get a nice clean String!
macro_rules! own_string {
($cstr:expr) => { ... };
}Convert a owned C string (i.e. owned by us now.) into a Rust String.
The C memory will be freed automatically, and you get a nice clean String!