Module func

Module func 

The internal PixelScript function logic.

Structs

Function
Basic rust structure to track Funcs and opaques together.
FunctionLookup
Lookup state structure

Functions

call_function
Call a function that is saved in the lookup by a idx.
clear_function_lookup
Clear function lookup hash
lookup_add_function
Add a function to the lookup

Type Aliases

pxs_Func
Function reference used in C.