call_function

Function call_function 

pub unsafe fn call_function(fn_idx: i32, args: Vec<pxs_Var>) -> pxs_Var
Call a function that is saved in the lookup by a idx.

This should only be used within languages and never from a end user.