#[unsafe(no_mangle)]pub extern "C" fn pxs_listinsert( list: pxs_VarT, index: usize, item: pxs_VarT, )
Insert a item into a list at a certain index, shifting all other items to the right.
Item ownership is transferred.