The internal PixelScript function logic.
Structs
- Function
- Basic rust structure to track Funcs and opaques together.
- Function
Lookup - Lookup state structure
Functions
- call_
function ⚠ - Call a function that is saved in the lookup by a idx.
- clear_
function_ lookup - Clear function lookup hash
- lookup_
add_ function - Add a function to the lookup
Type Aliases
- pxs_
Func - Function reference used in C.